RandomUnitary

Struct RandomUnitary 

pub struct RandomUnitary<T> { /* private fields */ }
A struct for generating random unitary matrices.

This struct creates a random matrix distributed according to the Haar measure, with complex case and an orthogonal matrix in the real case.

Example

use quantum_sim::random_gate::RandomUnitary;

let ru = RandomUnitary::<f64>::new(4).build();
let ru1 = RandomUnitary::<f64>::new(4).is_real(true).build();

Implementations

Source

impl<T> RandomUnitary<T>

pub fn new(dim_col: usize) -> Self

Creates a new RandomUnitary builder.

Arguments
  • dim_col - The number of columns for the matrix. By default, the matrix will be square (dim_row = dim_col).
pub fn dim(self, dim_row: usize) -> Self

Set row dimension (non-square matrices).

pub fn is_real(self, flag: bool) -> Self

Set to real matrix.

pub fn build(self) -> Array2<Complex<T>>

Builds the random unitary (or orthogonal) matrix.

Returns

An Array2<Complex<T>> representing the random matrix.