pub struct RandomUnitary<T> { /* private fields */ }Expand description
A struct for generating random unitary matrices.
This struct creates a random matrix distributed according to the Haar measure, with complex case and an orthogonal matrix in the real case.
Example
use quantum_sim::random_gate::RandomUnitary;
let ru = RandomUnitary::<f64>::new(4).build();
let ru1 = RandomUnitary::<f64>::new(4).is_real(true).build();Implementations